@@ -559,7 +559,7 @@ class Project(flow.Object):
         return success
     
     def log_out(self):
-        self.kitsu_api.log_out()()
+        self.kitsu_api().log_out()
     
     def kitsu_id(self):
         return self.admin.kitsu.project_id.get()
