@@ -497,6 +497,16 @@ class GenericRunAction(RunAction):
 
         return runner_name, []
 
+    def extra_env(self):
+        env = get_contextual_dict(self, "settings")
+        env["USER_NAME"] = self.root().project().get_user()
+        root_path = self.root().project().get_root()
+
+        if root_path:
+            env["ROOT_PATH"] = root_path
+
+        return env
+
     def get_version(self, button):
         ext = self._file.format.get()
         default_applications = self.root().project().admin.default_applications
@@ -643,11 +653,23 @@ class OpenTrackedFileAction(GenericRunAction):
 
 
 class OpenWithDefaultApp(RunAction):
+
     def runner_name_and_tags(self):
         return "DefaultEditor", []
 
+    def extra_env(self):
+        env = get_contextual_dict(self, "settings")
+        env["USER_NAME"] = self.root().project().get_user()
+        root_path = self.root().project().get_root()
+
+        if root_path:
+            env["ROOT_PATH"] = root_path
+
+        return env
+
 
 class OpenWithAction(OpenTrackedFileAction):
+    
     def runner_name_and_tags(self):
         raise NotImplementedError()
 
