@@ -9,6 +9,7 @@ from kabaret.subprocess_manager.flow import RunAction
 class KitsuAPIWrapper(flow.Object):
 
     _server_url = flow.Param("")
+    _config = flow.Parent()
 
     def set_host(self, url):
         gazu.client.set_host(url)
@@ -43,7 +44,6 @@ class KitsuAPIWrapper(flow.Object):
         gazu.client.set_tokens(tokens)
 
     def host_is_valid(self):
-        # return gazu.client.host_is_valid()
         if not gazu.client.host_is_up(gazu.client.default_client):
             return False
         try:
@@ -66,6 +66,43 @@ class KitsuAPIWrapper(flow.Object):
             return False
 
         return True
+    
+    def get_project_data(self):
+        return gazu.project.get_project_by_name(
+            self._config.project_name.get()
+        )
+    
+    def get_shot_data(self, shot_name, sequence_name):
+        sequence = self.get_sequence_data(sequence_name)
+        if not sequence:
+            return None
+        
+        return gazu.shot.get_shot_by_name(
+            sequence,
+            shot_name
+        )
+    
+    def get_shot_casting(self, shot):
+        return gazu.casting.get_shot_casting(shot)
+    
+    def get_sequence_data(self, name):
+        return gazu.shot.get_sequence_by_name(
+            self._config.project_id.get(),
+            name
+        )
+    
+    def get_asset_data(self, name):
+        return gazu.asset.get_asset_by_name(
+            self._config.project_id.get(),
+            name
+        )
+    
+    def get_asset_type(self, name):
+        asset = self.get_asset_data(name)
+        if not asset:
+            return None
+
+        return gazu.asset.get_asset_type(asset["entity_type_id"])
 
 
 class UpdateKitsuSettings(flow.Action):
